@@ -497,8 +497,17 @@ end
 -- Escaping strings
 ---------------------------------------------------------------------
 function escape ()
-        local escaped = CONN:escape"a'b'c'd"
+	local escaped = CONN:escape"a'b'c'd"
 	assert ("a\\'b\\'c\\'d" == escaped or "a''b''c''d" == escaped)
+
+	local n = 5200
+	local s1 = string.rep("'", n)
+	local s2 = CONN:escape(s1)
+	local s3 = s1:gsub ("'", "\\'")
+	assert (s1:len() == n)
+	assert (s2:len() == 2*n)
+	assert (s2 == s1..s1 or s2 == s3)
+
 	io.write (" escape")
 end
 
@@ -653,12 +662,21 @@ tests = {
 }
 
 if string.find(_VERSION, " 5.0") then
-	luasql = assert(loadlib("./"..driver..".so", "luaopen_luasql_"..driver))()
+	local init_so, err = loadlib("./"..driver..".so", "luaopen_luasql_"..driver)
+	if init_so then
+		luasql = init_so()
+	else
+		luasql = assert(loadlib("/usr/local/lib/lua/5.0/luasql/"..driver..".so", "luaopen_luasql_"..driver))()
+	end
 else
 	luasql = require ("luasql."..driver)
 end
 assert (luasql, "Could not load driver: no luasql table.")
-io.write (luasql._VERSION.." "..driver.." driver test.  "..luasql._COPYRIGHT.."\n")
+io.write (luasql._VERSION.." "..driver)
+if luasql._CLIENTVERSION then
+	io.write (" ("..luasql._CLIENTVERSION..")")
+end
+io.write (" driver test.  "..luasql._COPYRIGHT.."\n")
 
 for i = 1, table.getn (tests) do
 	local t = tests[i]
